@@ -10,108 +10,11 @@ class CMSOrders {
 		$this->taboptarray = array('mysql' => 'TYPE=MyISAM');
 	}
 
-	function CalculateDueDate( $p_startdate, $p_duedays ) {
-		/**
-		 * This function calculates the next date only using business days
-		 * @param startdate The start date
-		 * @param duedays   Number of days to add
-		 * Holidays are not looked at
-		 */
-	    $t_datecalc = $p_startdate;
-	 
-	    $i = 1;
-	    while ( $i <= $p_duedays ) {
-	        $t_datecalc  += 86400; // Add a day.
-	        $t_date_info  = getdate( $t_datecalc );
-	 
-	        if ( ( $t_date_info["wday"] == 0 ) or ( $t_date_info["wday"] == 6 ) )  {
-	                $t_datecalc += 86400; // Add a day.
-	                continue;
-	        }
-	 
-	        $i++;
-	    }
-	 
-	    return $t_datecalc;
-	}
-
-	function DestroyTables() {
-		$db = cmsms()->GetDb();
-		$dict = NewDataDictionary($db);
-
-		// Remove the database tables and sequences
-		$sqlarray = $dict->DropTableSQL( cms_db_prefix().'module_cartms_carts' );
-		$dict->ExecuteSQLArray($sqlarray);
-		$db->DropSequence( cms_db_prefix().'module_cartms_carts_seq' );
-
-		$sqlarray = $dict->DropTableSQL( cms_db_prefix().'module_cartms_orders' );
-		$dict->ExecuteSQLArray($sqlarray);
-		$db->DropSequence( cms_db_prefix().'module_cartms_orders_seq' );
-
-		$sqlarray = $dict->DropTableSQL( cms_db_prefix().'module_cartms_order_lines' );
-		$dict->ExecuteSQLArray($sqlarray);
-		$db->DropSequence( cms_db_prefix().'module_cartms_order_lines_seq' );
-
-		$sqlarray = $dict->DropTableSQL( cms_db_prefix().'module_cartms_shippingprovider' );
-		$dict->ExecuteSQLArray($sqlarray);
-		$db->DropSequence( cms_db_prefix().'module_cartms_shippingprovider_seq' );
-	}
-
-	function AddProduct($category_id, $product_id, $attribute_id = 0, $qty) {
-		$session_id = $this->GetSessionId();
-
-		$db = cmsms()->GetDb();
-
-		$query = 'SELECT COUNT(*) FROM '.cms_db_prefix().'module_cartms_carts 
-			WHERE session_id = ? AND category_id = ? AND product_id = ? AND attribute_id= ? ';
-		$dbresult = $db->Execute( $query, array( $session_id, $category_id, 
-			$product_id, $attribute_id));
-		$numRows = 0;
-		if ($dbresult && $row = $dbresult->FetchRow()) { 
-			$numRows = $row['COUNT(*)'];
-		}
-
-		if($numRows == 0 || $numRows =='0')	{
-			// This item doesn't exist in the users cart, we will add it with an insert query
-			$cart_id = $db->GenID(cms_db_prefix().'module_cartms_carts_seq');
-			// Creation time can be used to later reorganize the carts table (remove none actual requests)
-			$time = $db->DBTimeStamp(time());
-			$query = 'INSERT INTO '.cms_db_prefix().'module_cartms_carts (cart_id, 
-				session_id, category_id, product_id, attribute_id, qty, create_date) 
-				VALUES( ?, ?, ?, ?, ?, ?, '.$time.' )';
-			$db->Execute($query, array($cart_id, $session_id, $category_id, 
-				$product_id, $attribute_id, $qty ));
-		}
-		else
-		{
-			// This item already exists in the users cart, we will update it instead
-			$this->UpdateProduct($session_id, $product_id, $attribute_id, $qty);
-		}
-		
-	}
-
-	function UpdateProduct($session_id, $product_id, $attribute_id, $qty) {
-		$db = cmsms()->GetDb();
-
-		$query = 'UPDATE '.cms_db_prefix().'module_cartms_carts SET qty = ? 
-			WHERE session_id = ? AND product_id = ? AND attribute_id = ?';
-		$db->Execute($query, array($qty, $session_id, $product_id, $attribute_id));
-	}
-
-	function RemoveProduct( $product_id, $attribute_id) {
-		$db = cmsms()->GetDb();
-		
-		$query = "DELETE FROM ".cms_db_prefix()."module_cartms_carts 
-			WHERE session_id = '" . $this->GetSessionId() . "' AND product_id = ?
-			AND attribute_id = ?";
-		$db->Execute($query, array($product_id, $attribute_id));
-	}
-
 	function ClearCart() {
 		$db = cmsms()->GetDb();
 		
 		$query = 'DELETE FROM '.cms_db_prefix().'module_cartms_carts 
-			WHERE session_id = \'' . $this->GetSessionId().'\'';
+			WHERE session_id = \'' . cartms_utils::GetSessionId().'\'';
 		$db->Execute($query);
 	}
 
@@ -132,7 +35,7 @@ class CMSOrders {
 			cart.product_id = prd.product_id 
 			LEFT OUTER JOIN ".cms_db_prefix()."module_sms_product_attributes attr ON
 			cart.attribute_id = attr.attribute_id 
-			WHERE cart.session_id = '" . $this->GetSessionId() . "'
+			WHERE cart.session_id = '" . cartms_utils::GetSessionId() . "'
 			ORDER BY cart.cart_id ASC, prd.product_id ASC, attr.attribute_id ASC";
 		$dbresult = $db->Execute($query);
 		$rowclass = 'row1';
@@ -183,11 +86,13 @@ class CMSOrders {
 				$qtydropdown[$i] = $i;
 			}
 			$onerow->qtydropdown = $qtydropdown;
+			$prettyurl = 'CartMadeSimple/rmv/'.$row['product_id'].'/'.$row['attribute_id'].'/';
+			$prettyurl .= ($detailpage!=''?$detailpage:$returnid);
 			$onerow->deletelink = $this->module->CreateLink($id, 'cart', $returnid, 
 				#$this->module->$gCms->variables['admintheme']->DisplayImage('icons/system/delete.gif', $this->module->Lang('delete'),'','','systemicon'),
 				$this->module->Lang('remove_product_from_cart'), 
 				array('perfaction'=>'remove_product', 'product_id'=>$row['product_id'], 
-					'attribute_id'=>$row['attribute_id']));
+					'attribute_id'=>$row['attribute_id']), '', false, true, '', true, $prettyurl);
 
 			$entryarray[] = $onerow;
 
@@ -205,7 +110,7 @@ class CMSOrders {
 		$db = cmsms()->GetDb();
 		$totalnetweight = 0;
 		$totalnetprice = 0;
-		$session_id = $this->GetSessionId(); 
+		$session_id = cartms_utils::GetSessionId(); 
 		
 		$query = 'SELECT * FROM '.cms_db_prefix().'module_cartms_carts WHERE session_id = ?';
 		$dbresult = $db->Execute($query, array( $session_id ));
@@ -235,24 +140,6 @@ class CMSOrders {
 		return $cartinfo;
 	}
 
-	function GetSessionId() {
-		// This function will generate an encrypted string and will set it as a cookie using set_cookie. This will
-		// also be used as the cookieId field in the cart table
-
-		if(isset($_COOKIE["session_id"]))
-		{
-			return $_COOKIE["session_id"];
-		}
-		else
-		{
-			// There is no cookie set. We will set the cookie and return the value of the users session ID
-			// Expiration time of cookie is set to 30 days
-			session_start();
-			setcookie("session_id", session_id(), time() + ((3600 * 24) * 30));
-			return session_id();
-		}
-	}
-
 	function CheckOrderExists( $order_id ) {
 		$db = cmsms()->GetDb();
 		$dict = NewDataDictionary($db);
@@ -283,45 +170,6 @@ class CMSOrders {
 		}
 	}
 	
-	function GetOrderHeader( $order_id ) {
-		$db = cmsms()->GetDb();
-		$dict = NewDataDictionary($db);
-		$sql = "SELECT order_id,
-				totalproduct,
-				totaldiscount,
-				totalshipping,
-				totaladmincost,
-				shipmode,
-				comment,
-				status,
-				customer_id,
-				currency,
-				paymethod,
-				totalnetweight,
-				totalvat0amount,
-				totalvat1amount,
-				totalvat2amount,
-				totalvat3amount,
-				totalvat4amount,
-				termsagreed,
-				remark,
-				coupon_code,
-				invoiceno,
-				delivery_date,
-				create_date
-			FROM ".cms_db_prefix()."module_cartms_orders
-					WHERE order_id=?";
-		$dbresult = $db->Execute( $sql, array( $order_id ));
-		if( !$dbresult ) {
-			return false;
-		}
-		$result = '';
-		while( $row = $dbresult->FetchRow() ) {
-			$result = $row;
-		}
-		return $result;
-	}
-
 	function GetOrderShipTo( $customer_id, $countryformating = true ) {
 	     // Retrieve the address from the module FrontEndUsers
 		$feusers =& $this->module->GetModuleInstance('FrontEndUsers');
@@ -702,27 +550,6 @@ class CMSOrders {
 		return $order_id;			
 	}
 
-	function GenerateUserPassword ($length = 8) {
-		// Script taken from Jon Haworth
-		// Start with a blank password
-		$password = '';
-		// Define possible characters
-		$possible = "0123456789bcdfghjkmnpqrstvwxyz"; 
-		// Set up a counter
-		$i = 0; 
-		// Add random characters to $password until $length is reached
-		while ($i < $length) { 
-			// Pick a random character from the possible ones
-			$char = substr($possible, mt_rand(0, strlen($possible)-1), 1);
-			// We don't want this character if it's already in the password
-			if (!strstr($password, $char)) { 
-			  $password .= $char;
-			  $i++;
-			}
-		}
-		return $password;
-	}
-
 	function SendCustomerConfirmationMail($orderheader) {
 		$db = cmsms()->GetDb();
 		// Retrieve the password of the customer so we can check if this is a brand new customer
@@ -857,40 +684,40 @@ class CMSOrders {
 						redirect($config['root_url'].$text);
 						break;
 					case 'paypal':
-            // Set standard payment fields
-            $pgw->fields['rm'] = '2';
-         		$pgw->fields['business'] = $pgw->getGateWayValue ($gateway_code, 'business_email');
-         		$pgw->fields['return'] = $pgw->getGateWayValue ($gateway_code, 'return');
-         		//$pgw->fields['return'] = $pgw->getGateWayValue ($gateway_code, 'return').'?order='.$orderheader['order_id'];
-         		$pgw->fields['cancel_return'] = $pgw->getGateWayValue ($gateway_code, 'cancel_return');
-        		$pgw->fields['currency_code'] = $orderheader['currency'];
-							$numberofcents = $pgw->getGateWayValue ($gateway_code, 'numberofcents');
-							switch ($numberofcents) {
-								case '1' : 
-									$orderheader['totalproduct'] = $orderheader['totalproduct'] * 10;
-									$orderheader['totaldiscount'] = $orderheader['totaldiscount'] * 10;
-									$orderheader['totalshipping'] = $orderheader['totalshipping'] * 10;
-									$orderheader['totaladmincost'] = $orderheader['totaladmincost'] * 10;
-									$orderheader['totalvat0amount'] = $orderheader['totalvat0amount'] * 10;
-									$orderheader['totalvat1amount'] = $orderheader['totalvat1amount'] * 10;
-									$orderheader['totalvat2amount'] = $orderheader['totalvat2amount'] * 10;
-									$orderheader['totalvat3amount'] = $orderheader['totalvat3amount'] * 10;
-									$orderheader['totalvat4amount'] = $orderheader['totalvat4amount'] * 10;
-									break;
-								case '0' :
-									$orderheader['totalproduct'] = $orderheader['totalproduct'] * 100;
-									$orderheader['totaldiscount'] = $orderheader['totaldiscount'] * 100;
-									$orderheader['totalshipping'] = $orderheader['totalshipping'] * 100;
-									$orderheader['totaladmincost'] = $orderheader['totaladmincost'] * 100;
-									$orderheader['totalvat0amount'] = $orderheader['totalvat0amount'] * 100;
-									$orderheader['totalvat1amount'] = $orderheader['totalvat1amount'] * 100;
-									$orderheader['totalvat2amount'] = $orderheader['totalvat2amount'] * 100;
-									$orderheader['totalvat3amount'] = $orderheader['totalvat3amount'] * 100;
-									$orderheader['totalvat4amount'] = $orderheader['totalvat4amount'] * 100;
-									break;
-								default:
-									break;					
-							}
+						// Set standard payment fields
+						$pgw->fields['rm'] = '2';
+						$pgw->fields['business'] = $pgw->getGateWayValue ($gateway_code, 'business_email');
+						$pgw->fields['return'] = $pgw->getGateWayValue ($gateway_code, 'return');
+						//$pgw->fields['return'] = $pgw->getGateWayValue ($gateway_code, 'return').'?order='.$orderheader['order_id'];
+						$pgw->fields['cancel_return'] = $pgw->getGateWayValue ($gateway_code, 'cancel_return');
+						$pgw->fields['currency_code'] = $orderheader['currency'];
+						$numberofcents = $pgw->getGateWayValue ($gateway_code, 'numberofcents');
+						switch ($numberofcents) {
+							case '1' : 
+								$orderheader['totalproduct'] = $orderheader['totalproduct'] * 10;
+								$orderheader['totaldiscount'] = $orderheader['totaldiscount'] * 10;
+								$orderheader['totalshipping'] = $orderheader['totalshipping'] * 10;
+								$orderheader['totaladmincost'] = $orderheader['totaladmincost'] * 10;
+								$orderheader['totalvat0amount'] = $orderheader['totalvat0amount'] * 10;
+								$orderheader['totalvat1amount'] = $orderheader['totalvat1amount'] * 10;
+								$orderheader['totalvat2amount'] = $orderheader['totalvat2amount'] * 10;
+								$orderheader['totalvat3amount'] = $orderheader['totalvat3amount'] * 10;
+								$orderheader['totalvat4amount'] = $orderheader['totalvat4amount'] * 10;
+								break;
+							case '0' :
+								$orderheader['totalproduct'] = $orderheader['totalproduct'] * 100;
+								$orderheader['totaldiscount'] = $orderheader['totaldiscount'] * 100;
+								$orderheader['totalshipping'] = $orderheader['totalshipping'] * 100;
+								$orderheader['totaladmincost'] = $orderheader['totaladmincost'] * 100;
+								$orderheader['totalvat0amount'] = $orderheader['totalvat0amount'] * 100;
+								$orderheader['totalvat1amount'] = $orderheader['totalvat1amount'] * 100;
+								$orderheader['totalvat2amount'] = $orderheader['totalvat2amount'] * 100;
+								$orderheader['totalvat3amount'] = $orderheader['totalvat3amount'] * 100;
+								$orderheader['totalvat4amount'] = $orderheader['totalvat4amount'] * 100;
+								break;
+							default:
+								break;					
+						}
 
 						// Prepare setting if only one line with amount or a cart situation with multiple lines possible
 						if ( $pgw->getGatewayValue('PayPal', 'cartstyle') == '0' ) {
@@ -914,21 +741,21 @@ class CMSOrders {
 						}
 						else {
 							// Details to be prepared for PayPal 'cart'
-         			$pgw->fields['cmd'] = '_cart';
-        			$pgw->fields['upload'] = '1';
-              $orderlines = array();
-              $orderlines = $this->GetOrderLines($orderheader['order_id']);
-              $line = 1;
-              foreach ($orderlines as $orderline)
-              {
-								$pgw->fields['item_name_'.$line] = $orderline->productname;
-                if ($orderline->attributename != '') {
-									$pgw->fields['item_name_'.$line] .= ' ('.$orderline->attributename.')';								
-								}
-                $pgw->fields['quantity_'.$line] = $orderline->qty;
-                $pgw->fields['amount_'.$line] = strtr($orderline->price, ',', '.');
-                $line++;
-              }
+							$pgw->fields['cmd'] = '_cart';
+							$pgw->fields['upload'] = '1';
+							$orderlines = array();
+							$orderlines = $this->GetOrderLines($orderheader['order_id']);
+							$line = 1;
+							foreach ($orderlines as $orderline)
+							{
+										$pgw->fields['item_name_'.$line] = $orderline->productname;
+							if ($orderline->attributename != '') {
+											$pgw->fields['item_name_'.$line] .= ' ('.$orderline->attributename.')';								
+										}
+							$pgw->fields['quantity_'.$line] = $orderline->qty;
+							$pgw->fields['amount_'.$line] = strtr($orderline->price, ',', '.');
+							$line++;
+							}
 							if ( round($orderheader['totalshipping'], $numberofcents) > 0 ) {
 								$pgw->fields['shipping_1'] = strtr(round($orderheader['totalshipping'], $numberofcents), ',', '.');
 							}
@@ -963,7 +790,7 @@ class CMSOrders {
 		// Order has been paid, calculate and set the expected delivery date based upon delivery method
 		$db = cmsms()->GetDb();
 		$orderheader = array();
-		$orderheader = $this->GetOrderHeader( $order_id );
+		$orderheader = cartms_utils::GetOrderHeader( $order_id );
 		$shipmode = $orderheader['shipmode'];
 		$query = 'SELECT * FROM '.cms_db_prefix().'module_cartms_shippingprovider WHERE shipprovcode = ? ';
 		$dbresult = $db->Execute( $query, array( $shipmode ));
@@ -973,7 +800,7 @@ class CMSOrders {
 			if ($shipworkdays == 0) {
 				$newdeliverydate = time();
 			} else {
-				$newdeliverydate = $this->CalculateDueDate( time(), $shipworkdays );
+				$newdeliverydate = cartms_utils::CalculateDueDate( time(), $shipworkdays );
 			}
 			// Now that new expected delivery date is known, update the order
 			$query = 'UPDATE '.cms_db_prefix().'module_cartms_orders SET delivery_date = '.$db->DBTimeStamp($newdeliverydate).',
@@ -993,6 +820,9 @@ class CMSOrders {
 	function SwitchStatus( $params ) {
 		// Initialize the Database
 		$db = cmsms()->GetDb();
+		if (isset($params['id'])) {
+			$id = $params['id'];
+		}
 		
 		$query = 'UPDATE '.cms_db_prefix().'module_cartms_orders SET status = ?, 
 			modified_date = '.$db->DBTimeStamp(time()).' WHERE order_id = ?';
@@ -1043,6 +873,7 @@ class CMSOrders {
 			// Check if inventory to be decreased
 			$this->module->InventoryDecrease($params['order_id'], $newstatus);
 		}
+		
 	    // Redirect the user to the default admin screen if requested, else leave up to calling program
 	    if (isset($params['active_tab'])) {
 			$params = array('active_tab' => 'order');
@@ -1050,129 +881,6 @@ class CMSOrders {
 	    }
     }
 
-	function StoreShipInfo( $params ) 	{
-		// In the second step of the order processing, the visitor has entered a ship to address
-		// Now that we know it, store it using FEU for later usage
-	  // At this moment we're allowing instant registration (so no checks)
-		$feusers =& $this->module->GetModuleInstance('FrontEndUsers');
-		if( !$feusers )
-		{
-			// Set the id of the current user
-			$currentuser = $this->smarty->get_template_vars('customcontent_loggedin');
-			if (!$currentuser > 0) {
-				
-			}
-			
-		}
-		else
-		{
-			$db = cmsms()->GetDb();
-			$dict = NewDataDictionary($db);
-			// Check what the preferences are for the username in FEU
-			$randomusername = $feusers->GetPreference('use_randomusername', 0);
-			$username_is_email = $feusers->GetPreference('username_is_email', 0);
-			if ($randomusername != 0)
-			{
-				// Prepare a random name using FEU api
-				$username = $feusers->GenerateRandomUsername();
-			}
-			else
-			{
-				if ($username_is_email != 0 )
-				{
-					$username = $params['email'];
-				}
-				else
-				{
-					$username = $params['firstname'].' '.$params['lastname'];
-					$username = str_replace(' ', '_', $username);
-				}
-			}
-			// Now check if the user already exists
-			$query = 'SELECT * FROM '.cms_db_prefix().'module_feusers_users WHERE username = ?';
-			$row = $db->GetRow($query, array($username));
-			if( !$row )	{
-				$group_id = $feusers->GetGroupID('CartMadeSimple');
-				$password = $this->GenerateUserPassword();
-				$expires = strtotime('+5 years');
-				// Add the customer
-				$result = $feusers->AddUser( $username, $password, $expires );
-				// Retrieve the id
-				$query = 'SELECT * FROM '.cms_db_prefix().'module_feusers_users_seq';
-				$row = $db->GetRow($query);
-				$user_id = $row['id'];
-				// Save the password and name so it can be used in the first confirmation mail
-				$query = 'INSERT INTO '.cms_db_prefix().'module_cartms_newuserpasswords (user_id, password, username)
-					VALUES(?, ?, ?)';
-				$db->Execute($query, array($user_id, $password, $username ));
-				// Connect customer to group
-				#$result = $feusers->AssignUserToGroup( $user_id, $group_id );
-				$query = "INSERT INTO ".cms_db_prefix()."module_feusers_belongs VALUES (?,?)";
-				$db->Execute( $query, array( $user_id, $group_id ) );
-				// Address id (read user_id) is known
-				// Save the address in the connected property fields of customer
-				$result = $feusers->SetUserPropertyFull( 'email', $params['email'], $user_id );
-			}
-			else {
-				$user_id = $row['id'];
-			}
-			$result = $feusers->SetUserPropertyFull( 'firstname', $params['firstname'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'surname', $params['lastname'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'addressstreet', $params['addressstreet'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'addresscity', $params['addresscity'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'addressstate', $params['addressstate'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'addresszip', $params['addresszip'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'addresscountry', $params['addresscountry'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'telephone', $params['telephone'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'billfirstname', $params['billfirstname'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'billsurname', $params['billlastname'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'billaddressstreet', $params['billaddressstreet'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'billaddresscity', $params['billaddresscity'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'billaddressstate', $params['billaddressstate'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'billaddresszip', $params['billaddresszip'], $user_id );
-			$result = $feusers->SetUserPropertyFull( 'billaddresscountry', $params['billaddresscountry'], $user_id );
-			// Save the user_id for later
-			return $user_id;
-		}
-	}
-
-	function StoreDeliveryInfo( $params ) {
-		// In the third step of the order processing, the visitor has entered a delivery method
-		// Now that we know it, store it in the order
-		$db = cmsms()->GetDb();
-		$dict = NewDataDictionary($db);
-		
-		$deliverymethod = $params['deliverymethod'];
-		$agreetoterms = $params['agreetoterms'];
-		$order_id = $params['order_id'];
-		
-		// Retrieve the order header information which contains the net weight. The weight is used as a factor in delivery cost
-		$orderheader = array();
-		$orderheader = $this->GetOrderHeader( $order_id );
-
-		// Retrieve the shipping price, so it can be added in the order
-		$query = 'SELECT * FROM '.cms_db_prefix().'module_cartms_shippingprovider WHERE shipprovcode = ? ';
-		$dbresult = $db->Execute( $query, array( $deliverymethod ));
-		if ($dbresult && $row = $dbresult->FetchRow()) {
-			$totalshipping = $row['shipprovprice'] + $row['shippriceperweight'] * $orderheader['totalnetweight'];
-			$shipworkdays = $row['shipworkdays'];
-		}
-		else {
-			$totalshipping = 0;
-			$shipworkdays = 0;
-		}
-		if ($shipworkdays == 0) {
-			$newdeliverydate = time();
-		} else {
-			$newdeliverydate = $this->CalculateDueDate( time(), $shipworkdays );
-		}
-		$newdeliverydate = trim($db->DBTimeStamp($newdeliverydate), "'");
-
-		$query = 'UPDATE '.cms_db_prefix().'module_cartms_orders set shipmode = ?, totalshipping = ?, termsagreed = ?, delivery_date = ?
-			WHERE order_id = ?';
-		$db->Execute($query, array($deliverymethod, $totalshipping, $agreetoterms, $newdeliverydate, $order_id));
-	}
-
 	function StorePaymentInfo( $params ) {
 		// In the fourth step of the order processing, the visitor has entered a payment method
 		// Now that we know it, store it in the order
